@@ -198,7 +198,7 @@ int main (int argc, char *argv[])
 
   if (argc != 2)
   {
-    printf("\n  usage: s2x <filename>\n\n");
+    plintf("\n  usage: s2x <filename>\n\n");
     return 1;
   }
 
@@ -313,7 +313,7 @@ void GetEvents(Model_t *m)
       }
     na=Event_getNumEventAssignments(e);
     x->na=na;
-    printf("na=%d\n",na);
+    plintf("na=%d\n",na);
     for(j=0;j<na;j++){
       ea=Event_getEventAssignment(e, j);
       if ( EventAssignment_isSetMath(ea) ){
@@ -471,19 +471,19 @@ dump_reactions()
 {
   int i,j;  int npr,nre;
   RXN *r;
-  printf("REACTIONS:\n");
+  plintf("REACTIONS:\n");
   for(i=0;i<Nrxn;i++){
     r=rxn+i;
-    printf("rxn %d: %s \n",i,r->formula);
-    printf("reactants: ");
+    plintf("rxn %d: %s \n",i,r->formula);
+    plintf("reactants: ");
     npr=r->npr;
     nre=r->nre;
     for(j=0;j<nre;j++)
-      printf("%s(%g), ",r->re[j],r->sre[j]);
-    printf("\nproducts: ");
+      plintf("%s(%g), ",r->re[j],r->sre[j]);
+    plintf("\nproducts: ");
     for(j=0;j<npr;j++)
-      printf("%s(%g), ",r->pr[j],r->spr[j]);
-    printf("\n");
+      plintf("%s(%g), ",r->pr[j],r->spr[j]);
+    plintf("\n");
   }
 }
 dump_events()
@@ -493,11 +493,11 @@ dump_events()
   if(Nevent==0)return;
   for(i=0;i<Nevent;i++){
     ev=event+i;
-    printf("global 1 %s {",ev->ev);
+    plintf("global 1 %s {",ev->ev);
     na=ev->na;
     for(j=0;j<na-1;j++)
-      printf("%s;",ev->a[j]);
-    printf("%s}\n",ev->a[na-1]);
+      plintf("%s;",ev->a[j]);
+    plintf("%s}\n",ev->a[na-1]);
   }
 }
 dump_funs()
@@ -506,10 +506,10 @@ dump_funs()
   FUN_DEF *f;
   for(i=0;i<Nfuns;i++){
     f=funs+i;
-    printf("%s(",f->name);
+    plintf("%s(",f->name);
     for(j=0;j<f->nargs;j++)
-      printf("%s,",f->arg[j]);
-    printf(")=%s\n",f->formula);
+      plintf("%s,",f->arg[j]);
+    plintf(")=%s\n",f->formula);
   }
 }
 dump_rules()
@@ -517,29 +517,29 @@ dump_rules()
   RULE *r;
   int i;
   if(Nrule>0)
-    printf("RULES:\n");
+    plintf("RULES:\n");
   for(i=0;i<Nrule;i++){
     r=rule+i;
-    printf("%s=%s\n",r->v,r->f);
+    plintf("%s=%s\n",r->v,r->f);
   }
 }
 dump_species()
 {
   SPECIES *x;
   int i;
-  printf("SPECIES: n i t\n");
+  plintf("SPECIES: n i t\n");
   for(i=0;i<N_spec;i++){
     x=X_spec+i;
-    printf("%s %s %s %g %d %d \n",x->name,x->id,x->tc,x->x0,x->bc,x->c);
+    plintf("%s %s %s %g %d %d \n",x->name,x->id,x->tc,x->x0,x->bc,x->c);
   }
 }
 
 dump_parameters()
 {
   int i;
-  printf("PARAMETERS:\n");
+  plintf("PARAMETERS:\n");
   for(i=0;i<Npar;i++)
-    printf("%d %s %s = %g \n",par[i].fixed,par[i].name,par[i].id,par[i].z);
+    plintf("%d %s %s = %g \n",par[i].fixed,par[i].name,par[i].id,par[i].z);
 }
 add_species(int i,char *name,char *id,double x0,int bc,int c,char *tc)
 {
@@ -886,12 +886,12 @@ mark_rule_pars()
     j=find_parameter(r->v);
     if(j>-1){
       par[j].fixed=-2;
-      printf("found %s as %d \n",r->v,j);
+      plintf("found %s as %d \n",r->v,j);
     }
     j=find_species(r->v);
     if(j>-1){
       (X_spec+j)->rule=1;
-      printf("found %s as %d \n",r->v,j);
+      plintf("found %s as %d \n",r->v,j);
     }
   }
 }
@@ -958,7 +958,7 @@ check_name_len(char *s)
     strncpy(x,s,4);
     x[4]=0;
     sprintf(long_names[lnum].rep,"%s.%d",x,lnum);
-    printf("long name: %s -> %s \n",long_names[lnum].src,long_names[lnum].rep);
+    plintf("long name: %s -> %s \n",long_names[lnum].src,long_names[lnum].rep);
     lnum++;
   }
 }
@@ -1007,7 +1007,7 @@ int strfnd(char *s1,char *s2,int j0)
       false=0;
       l=i+j0;
       for(k=0;k<n1;k++){
-	/* printf("i=%d,k=%d,%c %c \n",i,k,s2[j0+i],s1[k]); */
+	/* plintf("i=%d,k=%d,%c %c \n",i,k,s2[j0+i],s1[k]); */
 	if(s2[j0+i]!=s1[k]){
 	  false=1;
 	  break;
@@ -1044,7 +1044,7 @@ sort_long_names()
   if(lnum<2)return; /* nothing to sort ! */
   qsort(long_names,lnum,sizeof(LONG_NAMES),z_sort);
   for(i=0;i<lnum;i++)
-    printf("%d: %s -> %s \n",i,long_names[i].src,long_names[i].rep);
+    plintf("%d: %s -> %s \n",i,long_names[i].src,long_names[i].rep);
   
 }
 
